@@ -5,7 +5,6 @@ use Digest::MD5;
 use File::ShareDir;
 use HTTP::Request;
 use HTTP::Request::Common;
-use LWP::UserAgent;
 use Test::More;
 use Test::TCP;
 use Plack::Loader;
@@ -13,6 +12,7 @@ use Plack::Middleware::Lint;
 use Plack::Util;
 use Plack::Request;
 use Try::Tiny;
+use Plack::LWPish;
 
 my $share_dir = try { File::ShareDir::dist_dir('Plack') } || 'share';
 
@@ -755,7 +755,7 @@ sub run_server_tests {
         client => sub {
             my $port = shift;
 
-            my $ua = LWP::UserAgent->new;
+            my $ua = Plack::LWPish->new;
             for my $i (0..$#TEST) {
                 my $test = $TEST[$i];
                 note $test->[0];
